#!/usr/bin/python3
# -*- coding: utf-8 -*-

import sys, os
import argparse
import re
import logging

# run:
# cd data
# ../conllu2trees_vert.py vert/ud21_gum_dev trees/ud21_gum_dev en_gum-ud-dev.conllu

#logging.basicConfig(format='%(levelname)s:%(message)s', level=logging.INFO)
logging.basicConfig(format='%(levelname)s:%(message)s', level=logging.DEBUG)

parser = argparse.ArgumentParser()
parser.add_argument("vertdir", type=str,
        help="directory to store all verticals")
parser.add_argument("treedir", type=str,
        help="directory to store all trees")
parser.add_argument('conllufile', nargs='?', type=argparse.FileType('r', encoding='utf-8'),
        default=sys.stdin, help="input conllu file or stdin")

args = parser.parse_args()

sentences = {}
trees = {}
sent = ''
tree = ''
sent_id = ''
skip_sent = False
for line in args.conllufile.readlines():
    m = re.match(r'^# sent_id = GUM_(whow_)?(.*)', line)
    if m:
        if sent_id and not skip_sent:
            sent += "</s>\n"
            sentences[sent_id] = sent
            trees[sent_id] = tree
        sent_id = m.group(2)
        logging.debug(f"new sent_id={sent_id}")
        sent = "<s>\n"
        tree = ''
        skip_sent = False
    elif re.match(r'^[^\d]', line) or re.match(r'^\d+-\d+', line):
        continue
    else:
        logging.debug(f"line={line}")
        if re.match(r'^\d+\.', line):
            skip_sent = True
            logging.debug(f"skipping this sentence")
            continue
        token = line.split('\t')
        sent += f"{token[1]}\t{token[2]}\t{token[4]}\n"
        tree += f"{int(token[0])-1}\t{token[1]}\t{int(token[6])-1}\td\n"

if sent_id:
    sent += "</s>\n"
    sentences[sent_id] = sent
    trees[sent_id] = tree

logging.info(f"{len(sentences)} sentences read")

for sent_id, sent in sentences.items():
    fname = os.path.join(args.vertdir,sent_id)
    logging.debug(f"writing vertical to {fname}")
    with open(fname, 'w', encoding='utf-8') as f:
        f.write(sent)

for sent_id, tree in trees.items():
    fname = os.path.join(args.treedir,sent_id)
    logging.debug(f"writing tree to {fname}")
    with open(fname, 'w', encoding='utf-8') as f:
        f.write(tree)
